# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["Variant"]


class Variant(BaseModel):
    image_url: str

    product_id: str

    title: str
